@@ -12,8 +12,8 @@ ExerciseWindow::ExerciseWindow(QWidget *parent) :
     setAttribute(Qt::WA_Maemo5StackedWindow);
     widget = new QWidget();
 
-    running = false;
     mx = 0; my = 0; mz = 0;
+    proximity = false;
 
     sw = new SettingsWindow(this);
     sw->hide();
@@ -55,6 +55,8 @@ ExerciseWindow::ExerciseWindow(QWidget *parent) :
     myThread = new aThread(this);
     connect(myThread, SIGNAL(deviceOrientation(QString, QString, QString)),
             this, SLOT(checkAcc(QString)));
+    connect(myThread, SIGNAL(proximityState(QString)),
+            this, SLOT(checkProximity(QString)));
 
 
     interface = new QDBusInterface(MCE_SERVICE, MCE_REQUEST_PATH,
@@ -129,7 +131,6 @@ void ExerciseWindow::loadExercise(QList<QString> name)
 
     set = SET; reps = REPS; min = MIN; sec = SEC;
     strSet.setNum(SET); strReps.setNum(REPS); strMin.setNum(MIN);  strSec.setNum(SEC);
-    label->setText("");
     label->setText(currentExercise + "\n Shake when done " + strReps + " reps");
     btnShake->setEnabled(true);
     myThread->start(QThread::NormalPriority);
@@ -262,24 +263,34 @@ void ExerciseWindow::skipWait()
     sec = 0;
 }
 
+void ExerciseWindow::checkProximity(QString data)
+{
+    if(data.left(6) == "closed")
+    {
+        proximity = true;
+    }
+    else
+    {
+        proximity = false;
+    }
+
+}
+
 void ExerciseWindow::checkAcc(QString x)
 {
-    /*
-    QSensor sensor(QProximitySensor);
-    sensor->connect();
-    sensor->start();
 
-    QProximityReading *reading = sensor->reading();
-*/
     if(x.toInt() > 2200 || x.toInt() < -2200)
     {
-        vibrate();
-        tmr = new QTimer(this);
-        tmr->setSingleShot(true);
-        QObject::connect(tmr, SIGNAL(timeout()), this, SLOT(stopVibrate()));
-        tmr->start(1000);  //ndra hr fr olika vibrationslngd
+        if(proximity == false)
+        {
+            vibrate();
+            tmr = new QTimer(this);
+            tmr->setSingleShot(true);
+            QObject::connect(tmr, SIGNAL(timeout()), this, SLOT(stopVibrate()));
+            tmr->start(1000);  //ndra hr fr olika vibrationslngd
 
-        shaked();
+            shaked();
+        }
 
     }
 }
