@@ -11,6 +11,16 @@ FoodDialog::FoodDialog(QWidget *parent)
 
     vLayout = new QVBoxLayout();
 
+    modelType = new QStandardItemModel(this);
+    modelType->appendRow(new QStandardItem(tr("Drink")));
+    modelType->appendRow(new QStandardItem(tr("Food")));
+
+    btnType = new QMaemo5ValueButton("Product");
+    btnType->setValueLayout(QMaemo5ValueButton::ValueUnderText);
+    selectorType = new QMaemo5ListPickSelector;
+    selectorType->setModel(modelType);
+    btnType->setPickSelector(selectorType);
+
     modelName = new QStandardItemModel(this);
 
     btnName = new QMaemo5ValueButton("Product");
@@ -33,6 +43,7 @@ FoodDialog::FoodDialog(QWidget *parent)
     btnAdd = new QPushButton("Add");
     connect(btnAdd,SIGNAL(clicked()),this,SLOT(save()));
 
+    vLayout->addWidget(btnType);
     vLayout->addWidget(btnName);
     vLayout->addWidget(btnAmount);
     vLayout->addWidget(btnAdd);
