@@ -163,6 +163,11 @@ void InfoWindow::createActions()
     connect(btnBack, SIGNAL(clicked()), this, SLOT(back()));
 }
 
+void InfoWindow::changeEvent(QEvent *event)
+{
+    if(event->type() == QEvent::ActivationChange)
+        loadExercise(exerciseName);
+}
 
 void InfoWindow::loadExercise(QString name)
 {
@@ -172,7 +177,7 @@ void InfoWindow::loadExercise(QString name)
     QString reps[3], currentReps;
 
     exerciseName = name;
-    qDebug() << name;
+
     list = xml->openEx(exerciseName);
     lblName->setText(list.takeFirst());
     list.takeFirst();
