@@ -42,6 +42,12 @@ ListWindow::ListWindow(QWidget *parent) :
 
 }
 
+void ListWindow::changeEvent(QEvent *event)
+{
+    if(event->type() == QEvent::ActivationChange)
+        loadExercises(group);
+}
+
 void ListWindow::loadExercises(QString grp)
 {
     QList <QString> list;
@@ -68,31 +74,6 @@ void ListWindow::loadExercises(QString grp)
     model->sort(0);
 }
 
-/*void ListWindow::loadDate(QString date)
-{
-    QList <QString> tmp;
-    QString name, grp, reps, var;
-
-    lstExercises->setSelectionMode(QListView::NoSelection);
-    setWindowTitle(date);
-    model->clear();
-    exercises = xml->getHistoryByDate(date);
-
-    while(!exercises.isEmpty())
-    {
-        tmp = exercises.takeFirst();
-        name = tmp.takeFirst();
-        grp = tmp.takeFirst();
-        var = tmp.takeFirst();
-        reps = tmp.takeFirst();
-
-        if(grp != "Cardio")
-            model->appendRow(new QStandardItem(grp + "/" + name + ": " + var + "Kg - " + reps + " reps"));
-        else
-            model->appendRow(new QStandardItem(grp + "/" + name + ": " + var + "Km" + " - " + reps));
-    }
-}
-*/
 void ListWindow::showNewIngredient()
 {
     niw->load();
